pub enum SitePackagesDiscoveryError {
CanonicalizationError(SystemPathBuf, SysPrefixPathOrigin, Error, Box<dyn System>),
PathNotExecutableOrDirectory(SystemPathBuf, SysPrefixPathOrigin, Option<Error>, Box<dyn System>),
NoPyvenvCfgFile(SysPrefixPath, Error, Box<dyn System>),
PyvenvCfgParseError(SystemPathBuf, PyvenvCfgParseErrorKind),
CouldNotReadLibDirectory(SysPrefixPath, Box<dyn System>),
NoSitePackagesDirFound(SysPrefixPath, Box<dyn System>),
}Expand description
Enumeration of ways in which site-packages discovery can fail.
Variants
CanonicalizationError(SystemPathBuf, SysPrefixPathOrigin, Error, Box<dyn System>)
site-packages discovery failed because the provided path couldn’t be canonicalized.
PathNotExecutableOrDirectory(SystemPathBuf, SysPrefixPathOrigin, Option<Error>, Box<dyn System>)
site-packages discovery failed because the provided path doesn’t appear to point to
a Python executable or a sys.prefix directory.
NoPyvenvCfgFile(SysPrefixPath, Error, Box<dyn System>)
site-packages discovery failed because the SysPrefixPathOrigin indicated that
the provided path should point to the sys.prefix of a virtual environment,
but there was no file at <sys.prefix>/pyvenv.cfg.
PyvenvCfgParseError(SystemPathBuf, PyvenvCfgParseErrorKind)
site-packages discovery failed because the pyvenv.cfg file could not be parsed.
CouldNotReadLibDirectory(SysPrefixPath, Box<dyn System>)
site-packages discovery failed because we’re on a Unix system,
we weren’t able to figure out from the pyvenv.cfg file exactly where site-packages
would be relative to the sys.prefix path, and we tried to fallback to iterating
through the <sys.prefix>/lib directory looking for a site-packages directory,
but we came across some I/O error while trying to do so.
NoSitePackagesDirFound(SysPrefixPath, Box<dyn System>)
We looked everywhere we could think of for the site-packages directory,
but none could be found despite our best endeavours.